@@ -28,6 +28,7 @@ class DataStore(ABC):
     def __contains__(self, item: str) -> bool:
         return self.contains(item)
 
+    # noinspection PyAttributeOutsideInit,PyProtectedMember
     @synchronized
     def get_branch(self, prefix: str,
                    value_generator: Callable[[str], Any] = None,
@@ -38,10 +39,16 @@ class DataStore(ABC):
             self._branches: Dict[str, DataStoreBranch] = dict()
         if prefix in self._branches:
             result: DataStoreBranch = self._branches[prefix]
-            if result._value_generator is not None and value_generator is not None:
-                raise ValueError(f'Branch with prefix "{prefix}" already has a value generator')
-            if result._change_indicator != SIMPLE_CHANGE_INDICATOR and change_indicator != SIMPLE_CHANGE_INDICATOR:
-                raise ValueError(f'Branch with prefix "{prefix}" already has a change indicator')
+            if value_generator is not None:
+                if result._value_generator is not None:
+                    raise ValueError(f'Branch with prefix "{prefix}" already has a value generator')
+                else:
+                    result._value_generator = value_generator
+            if change_indicator != SIMPLE_CHANGE_INDICATOR:
+                if result._change_indicator != SIMPLE_CHANGE_INDICATOR:
+                    raise ValueError(f'Branch with prefix "{prefix}" already has a change indicator')
+                else:
+                    result._change_indicator = change_indicator
             if change_event_handlers is not None and len(change_event_handlers) > 0:
                 if result._change_event_handlers is None:
                     result._change_event_handlers = change_event_handlers
